@@ -2,12 +2,14 @@
 
 .cropland_africa <- function(path, ...) {
 
-	.check_path(path)
+	path <- .get_path(path)
 	filename <- paste0("geosurvey_cropland.tif")
 	filepath <- file.path(path, filename)
 
 	if (!(file.exists(filepath))) {
-		url <- paste0(.data_url(), "landuse/", filename)
+		url <- .data_url(paste0("landuse/", filename))
+		if (is.null(url)) return(NULL)
+		
 		if (!.downloadDirect(url, filepath, ...)) return(NULL)
 		
 		r <- try(rast(filepath))
@@ -25,12 +27,15 @@
 
 
 .cropland_world <- function(path, ...) {
-	.check_path(path)
+
+	path <- .get_path(path)
 	filename <- paste0("WorldCover_cropland_30s.tif")
 	filepath <- file.path(path, filename)
 
 	if (!(file.exists(filepath))) {
-		url <- paste0(.data_url(), "landuse/", filename)
+		url <- .data_url(paste0("landuse/", filename))
+		if (is.null(url)) return(NULL)
+		
 		if (!.downloadDirect(url, filepath, ...)) return(NULL)
 		
 		r <- try(rast(filepath))
@@ -49,7 +54,8 @@
 
 
 .cropland_glad <- function(path, year, ...) {
-	.check_path(path)
+
+	path <- .get_path(path)
 	if (missing(year)) {
 		filename <- "glad_cropland.tif"
 	} else {
@@ -59,7 +65,9 @@
 	}
 	filepath <- file.path(path, filename)
 	if (!(file.exists(filepath))) {
-		url <- paste0(.data_url(), "cropland/", filename)
+		url <- .data_url(paste0("cropland/", filename))
+		if (is.null(url)) return(NULL)
+		
 		if (!.downloadDirect(url, filepath, ...)) return(NULL)
 		r <- try(rast(filepath))
 		if (inherits(r, "try-error")) {
@@ -74,7 +82,8 @@
 }
 
 cropland <- function(source, path, year, ...) {
-	.check_path(path)
+
+	path <- .get_path(path)
 	source = match.arg(trimws(tolower(source)), c("qed", "worldcover", "glad"))
 	if (source == "qed") {
 		.cropland_africa(path, ...)
@@ -87,7 +96,8 @@ cropland <- function(source, path, year, ...) {
 
 
 landcover <- function(var, path, ...) {
-	.check_path(path)
+
+	path <- .get_path(path)
 	
 	cats <- c("trees", "grassland", "shrubs", "cropland", "built", "bare", "snow", "water", "wetland", "mangroves", "moss")	
 	var <- tolower(var)
@@ -99,7 +109,9 @@ landcover <- function(var, path, ...) {
 	filepath <- file.path(path, filename)
 
 	if (!(file.exists(filepath))) {
-		url <- paste0(.data_url(), "landuse/", filename)
+		url <- .data_url(paste0("landuse/", filename))
+		if (is.null(url)) return(NULL)
+		
 		if (!.downloadDirect(url, filepath, ...)) return(NULL)
 		
 		r <- try(rast(filepath))
@@ -116,7 +128,7 @@ landcover <- function(var, path, ...) {
 
 
 footprint <- function(year=2009, path, ...) {
-	.check_path(path)
+	path <- .get_path(path)
 	
 	year <- as.character(year)
 	stopifnot(year %in% c("1993", "2009"))
@@ -124,7 +136,9 @@ footprint <- function(year=2009, path, ...) {
 	filepath <- file.path(path, filename)
 
 	if (!(file.exists(filepath))) {
-		url <- paste0(.data_url(), "footprint/", filename)
+		url <- .data_url(paste0("footprint/", filename))
+		if (is.null(url)) return(NULL)
+		
 		if (!.downloadDirect(url, filepath, ...)) return(NULL)
 		
 		r <- try(rast(filepath))
